package com.jiuqi.util;

import java.io.File;
import java.util.jar.Attributes;
import java.util.jar.Manifest;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/BundleUtils.class */
public class BundleUtils {
    public static String getBundleId(String path) {
        return getBundleId(new File(path));
    }

    public static String getBundleId(File path) {
        Manifest manifest = ManifestUtil.getManifest(path);
        if (manifest == null) {
            return null;
        }
        Attributes attrs = manifest.getMainAttributes();
        String bundleId = ManifestUtil.getAttributeValue(attrs, ManifestConstants.BUNDLE_SYMBOLIC_NAME);
        return bundleId;
    }

    public static boolean isBundle(String path) {
        return isBundle(new File(path));
    }

    public static boolean isBundle(File path) {
        String id = getBundleId(path);
        return (id == null || "".equals(id)) ? false : true;
    }

    public static boolean isHostBundle(String path) {
        return isHostBundle(new File(path));
    }

    public static boolean isHostBundle(File path) {
        Manifest manifest = ManifestUtil.getManifest(path);
        if (manifest == null) {
            return false;
        }
        Attributes attrs = manifest.getMainAttributes();
        String bundleId = ManifestUtil.getAttributeValue(attrs, ManifestConstants.BUNDLE_SYMBOLIC_NAME);
        if (bundleId == null) {
            return false;
        }
        String bundleLocalization = ManifestUtil.getAttributeValue(attrs, ManifestConstants.BUNDLE_LOCALIZATION);
        return bundleLocalization == null || "plugin".equalsIgnoreCase(bundleLocalization);
    }

    public static boolean isFragmentBundle(String path) {
        return isFragmentBundle(new File(path));
    }

    public static boolean isFragmentBundle(File path) {
        Manifest manifest = ManifestUtil.getManifest(path);
        if (manifest == null) {
            return false;
        }
        Attributes attrs = manifest.getMainAttributes();
        String bundleId = ManifestUtil.getAttributeValue(attrs, ManifestConstants.BUNDLE_SYMBOLIC_NAME);
        if (bundleId == null) {
            return false;
        }
        String fragmentHost = ManifestUtil.getAttributeValue(attrs, ManifestConstants.FRAGMENT_HOST);
        if (fragmentHost != null) {
            return true;
        }
        String bundleLocalization = ManifestUtil.getAttributeValue(attrs, ManifestConstants.BUNDLE_LOCALIZATION);
        return "fragment".equalsIgnoreCase(bundleLocalization);
    }
}
